@@ -171,7 +171,7 @@
         x = (x + ((x >> 8) & 0xff00ff)) >> 8;                       \
         x &= 0xff00ff;                                              \
         x += (y >> 8) & 0xff00ff;                                   \
-        x |= 0x1000100 - ((t >> 8) & 0xff00ff);                     \
+        x |= 0x1000100 - ((x >> 8) & 0xff00ff);                     \
         x &= 0xff00ff;                                              \
         x <<= 8;                                                    \
         x += t;                                                     \
