@@ -40,6 +40,7 @@ is" without express or implied warranty.
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
+#include <libgen.h>
 
 #ifdef __sun
 #include <strings.h>
@@ -56,6 +57,7 @@ is" without express or implied warranty.
 #include "servermd.h"
 #include "opaque.h"
 
+#include "Init.h"
 #include "Agent.h"
 #include "Display.h"
 #include "Args.h"
@@ -124,7 +126,7 @@ extern int _XGetBitsPerPixel(Display *dpy, int depth);
 
 extern char dispatchExceptionAtReset;
 
-const char *nxagentProgName;
+char *nxagentProgName;
 
 char nxagentDisplayName[NXAGENTDISPLAYNAMELENGTH];
 Bool nxagentSynchronize = False;
@@ -187,7 +189,14 @@ int ddxProcessArgument(int argc, char *argv[], int i)
    * Ensure that the options are set to their defaults.
    */
 
-  nxagentProgName = argv[0];
+  char *basec = strdup(argv[0]);
+  nxagentProgName = strdup(basename(basec));
+  free(basec);
+
+  /*
+   * Check if we running as X2Go Agent
+   */
+  checkX2goAgent();
 
   static Bool resetOptions = True;
 
@@ -1037,17 +1046,52 @@ int ddxProcessArgument(int argc, char *argv[], int i)
   return 0;
 }
 
-static void nxagentParseOptions(char *name, char *value)
+/* copy from nxcomp's Loop.cpp */
+static int
+hexval(char c) {
+    if ((c >= '0') && (c <= '9'))
+        return c - '0';
+    if ((c >= 'a') && (c <= 'f'))
+        return c - 'a' + 10;
+    if ((c >= 'A') && (c <= 'F'))
+        return c - 'A' + 10;
+    return -1;
+}
+
+static void
+URLDecodeInPlace(char *str)
+{
+  if (str) {
+    char *to = str;
+    while (str[0])
+    {
+      if ((str[0] == '%') &&
+          (hexval(str[1]) >= 0) &&
+          (hexval(str[2]) >= 0))
+      {
+        *(to++) = hexval(str[1]) * 16 + hexval(str[2]);
+        str += 3;
+      }
+      else
+        *(to++) = *(str++);
+    }
+    *to = '\0';
+  }
+}
+
+static void nxagentParseSingleOption(char *name, char *value)
 {
   int size, argc;
 
   char *argv[2] = { NULL, NULL };
 
   #ifdef TEST
-  fprintf(stderr, "nxagentParseOptions: Processing option '%s' = '%s'.\n",
+  fprintf(stderr, "nxagentParseSingleOption: Processing option '%s' = '%s'.\n",
               validateString(name), validateString(value));
   #endif
 
+  URLDecodeInPlace(value);
+
   if (!strcmp(name, "kbtype") ||
           !strcmp(name, "keyboard") ||
               !strcmp(name, "id") ||
@@ -1081,7 +1125,7 @@ static void nxagentParseOptions(char *name, char *value)
     if (nxagentReconnectTrap == True)
     {
       #ifdef DEBUG
-      fprintf(stderr, "nxagentParseOptions: Ignoring option 'render' at reconnection.\n");
+      fprintf(stderr, "nxagentParseSingleOption: Ignoring option 'render' at reconnection.\n");
       #endif
     }
     else if (nxagentRenderEnable == UNDEFINED)
@@ -1113,7 +1157,7 @@ static void nxagentParseOptions(char *name, char *value)
     if (nxagentReconnectTrap == True)
     {
       #ifdef DEBUG
-      fprintf(stderr, "nxagentParseOptions: Ignoring option 'fullscreen' at reconnection.\n");
+      fprintf(stderr, "nxagentParseSingleOption: Ignoring option 'fullscreen' at reconnection.\n");
       #endif
     }
     else if (!strcmp(value, "1"))
@@ -1283,7 +1327,7 @@ static void nxagentParseOptions(char *name, char *value)
     if (nxagentReconnectTrap == True)
     {
       #ifdef DEBUG
-      fprintf(stderr, "nxagentParseOptions: Ignoring option 'autodpi' at reconnection.\n");
+      fprintf(stderr, "nxagentParseSingleOption: Ignoring option 'autodpi' at reconnection.\n");
       #endif
     }
     else if (!strcmp(value, "0"))
@@ -1368,7 +1412,7 @@ static void nxagentParseOptions(char *name, char *value)
 
     if ((errno) && (0 == sleep_parse))
     {
-      fprintf(stderr, "nxagentParseOptions: Unable to convert value [%s] of option [%s]. "
+      fprintf(stderr, "nxagentParseSingleOption: Unable to convert value [%s] of option [%s]. "
                       "Ignoring option.\n",
                       validateString(value), validateString(name));
 
@@ -1379,7 +1423,7 @@ static void nxagentParseOptions(char *name, char *value)
     {
       sleep_parse = UINT_MAX;
 
-      fprintf(stderr, "nxagentParseOptions: Warning: value [%s] of option [%s] "
+      fprintf(stderr, "nxagentParseSingleOption: Warning: value [%s] of option [%s] "
                       "out of range, clamped to [%lu].\n",
                       validateString(value), validateString(name), sleep_parse);
     }
@@ -1388,7 +1432,7 @@ static void nxagentParseOptions(char *name, char *value)
     {
       sleep_parse = 0;
 
-      fprintf(stderr, "nxagentParseOptions: Warning: value [%s] of option [%s] "
+      fprintf(stderr, "nxagentParseSingleOption: Warning: value [%s] of option [%s] "
                       "out of range, clamped to [%lu].\n",
                       validateString(value), validateString(name), sleep_parse);
     }
@@ -1427,7 +1471,7 @@ static void nxagentParseOptions(char *name, char *value)
 
       if ((errno) && (0 == tolerance_parse))
       {
-        fprintf(stderr, "nxagentParseOptions: Unable to convert value [%s] of option [%s]. "
+        fprintf(stderr, "nxagentParseSingleOption: Unable to convert value [%s] of option [%s]. "
                         "Ignoring option.\n",
                         validateString(value), validateString(name));
 
@@ -1438,7 +1482,7 @@ static void nxagentParseOptions(char *name, char *value)
       {
         tolerance_parse = UINT_MAX;
 
-        fprintf(stderr, "nxagentParseOptions: Warning: value [%s] of option [%s] "
+        fprintf(stderr, "nxagentParseSingleOption: Warning: value [%s] of option [%s] "
                         "out of range, clamped to [%lu].\n",
                         validateString(value), validateString(name), tolerance_parse);
       }
@@ -1447,7 +1491,7 @@ static void nxagentParseOptions(char *name, char *value)
       {
         tolerance_parse = 0;
 
-        fprintf(stderr, "nxagentParseOptions: Warning: value [%s] of option [%s] "
+        fprintf(stderr, "nxagentParseSingleOption: Warning: value [%s] of option [%s] "
                         "out of range, clamped to [%lu].\n",
                         validateString(value), validateString(name), tolerance_parse);
       }
@@ -1460,7 +1504,7 @@ static void nxagentParseOptions(char *name, char *value)
         case ToleranceChecksBypass:
                                break;
         default:
-                               fprintf(stderr, "nxagentParseOptions: Warning: value [%s] of "
+                               fprintf(stderr, "nxagentParseSingleOption: Warning: value [%s] of "
                                                "option [%s] unknown, will be mapped to "
                                                "\"Bypass\" [%u] value internally.\n",
                                        validateString(value), validateString(name),
@@ -1495,7 +1539,7 @@ static void nxagentParseOptions(char *name, char *value)
   else
   {
     #ifdef DEBUG
-    fprintf(stderr, "nxagentParseOptions: Ignored option [%s] with value [%s].\n",
+    fprintf(stderr, "nxagentParseSingleOption: Ignored option [%s] with value [%s].\n",
                 validateString(name), validateString(value));
     #endif
 
@@ -1563,7 +1607,7 @@ static void nxagentParseOptionString(char *string)
       value = NULL;
     }
 
-    nxagentParseOptions(option, value);
+    nxagentParseSingleOption(option, value);
   }
 }
 
@@ -1770,7 +1814,14 @@ N/A
 
     if (*nxagentWindowName == '\0')
     {
-      snprintf(nxagentWindowName, NXAGENTWINDOWNAMELENGTH, "NX");
+      if(nxagentX2go)
+      {
+        snprintf(nxagentWindowName, NXAGENTWINDOWNAMELENGTH, "X2Go Agent");
+      }
+      else
+      {
+        snprintf(nxagentWindowName, NXAGENTWINDOWNAMELENGTH, "NX Agent");
+      }
     }
 
     /*
