@@ -106,7 +106,7 @@ static void catchAndRedirect(Display* dpy, XErrorEvent* X)
       X -> request_code == X_ChangeWindowAttributes &&
       X -> resourceid == DefaultRootWindow(dpy))
   {
-    nxagentWMIsRunning = TRUE;
+    nxagentWMIsRunning = True;
   }
   else
   {
@@ -122,7 +122,7 @@ static void startWMDetection(void)
    * window.
    */
 
-  nxagentWMIsRunning = FALSE;
+  nxagentWMIsRunning = False;
 
   previousErrorHandler = XSetErrorHandler((XErrorHandler)&catchAndRedirect);
 
@@ -166,7 +166,7 @@ static void finishWMDetection(Bool verbose)
 void nxagentWMDetect() 
 {
   Bool verbose = False;
-  int windowManagerWasRunning = nxagentWMIsRunning;
+  Bool windowManagerWasRunning = nxagentWMIsRunning;
 
   startWMDetection();
 
@@ -415,8 +415,8 @@ static void nxagentWriteAtom(Atom local, Atom remote, const char *string, Bool d
 
 /*
  * FIXME: We should clean up the atom map
- * at nxagent reset, in order to cancel 
- * all the local atoms but still mantaining 
+ * at nxagent reset, in order to cancel
+ * all the local atoms but still maintaining
  * the Xserver values and the atom names.
  */
 
@@ -470,8 +470,8 @@ static int nxagentInitAtomMap(char **atomNameList, int count, Atom *atomsRet)
   }
 
   /*
-   * Ask X-Server for ours Atoms
-   * ... if successfull cache them too.
+   * Ask X-Server for our Atoms
+   * ... if successful cache them too.
    */
 
   ret_value = XInternAtoms(nxagentDisplay, name_list, list_size, False, atom_list);
@@ -532,7 +532,7 @@ static int nxagentInitAtomMap(char **atomNameList, int count, Atom *atomsRet)
 }
 
 /*
- * If the nxagent has been resetted,
+ * If the nxagent has been reset,
  * the local value of the atoms stored
  * in cache could have the value None, 
  * do not call this function with None.
@@ -639,7 +639,7 @@ Atom nxagentMakeAtom(char *string, unsigned int length, Bool Makeit)
   {
     /*
      * Found Cached by name.
-     * It means that nxagent has been resetted,
+     * It means that nxagent has been reset,
      * but not the xserver so we still have cached its atoms.
      */
 
@@ -678,18 +678,31 @@ Atom nxagentLocalToRemoteAtom(Atom local)
   const char    *string;
   Atom    remote;
 
+  #ifdef TEST
+  fprintf(stderr, "%s: entering\n", __func__);
+  #endif
+
   if (!ValidAtom(local))
   {
+    #ifdef DEBUG
+    fprintf(stderr, "%s: local [%d] is no valid - returning None\n", __func__, remote);
+    #endif
     return None;
   }
 
   if (local <= XA_LAST_PREDEFINED)
   {
+    #ifdef DEBUG
+    fprintf(stderr, "%s: local [%d] is < XA_LAST_PREDEFINED [%d]\n", __func__, local, XA_LAST_PREDEFINED);
+    #endif
     return local;
   }
 
   if ((current = nxagentFindAtomByLocalValue(local)))
   {
+    #ifdef TEST
+    fprintf(stderr, "%s: local [%d] -> remote [%d]\n", __func__, local, current->remote);
+    #endif
     return current->remote;
   }
 
@@ -708,6 +721,10 @@ Atom nxagentLocalToRemoteAtom(Atom local)
 
   nxagentWriteAtom(local, remote, string, True);
 
+  #ifdef TEST
+  fprintf(stderr, "%s: local [%d] -> remote [%d (%s)]\n", __func__, local, remote, string);
+  #endif
+
   return remote;
 }
 
@@ -719,11 +736,17 @@ Atom nxagentRemoteToLocalAtom(Atom remote)
 
   if (remote == None || remote == BAD_RESOURCE)
   {
+    #ifdef DEBUG
+    fprintf(stderr, "%s: remote [%d] is None or BAD_RESOURCE\n", __func__, remote);
+    #endif
     return None;
   }
 
   if (remote <= XA_LAST_PREDEFINED)
   {
+    #ifdef DEBUG
+    fprintf(stderr, "%s: remote [%d] is <= XA_LAST_PREDEFINED [%d]\n", __func__, remote, XA_LAST_PREDEFINED);
+    #endif
     return remote;
   }
 
@@ -747,6 +770,9 @@ Atom nxagentRemoteToLocalAtom(Atom remote)
       }
     }
 
+    #ifdef DEBUG
+    fprintf(stderr, "%s: remote [%d] -> local [%d]\n", __func__, remote, current->local);
+    #endif
     return current->local;
   }
 
@@ -765,6 +791,9 @@ Atom nxagentRemoteToLocalAtom(Atom remote)
 
     nxagentWriteAtom(local, remote, string, True);
 
+    #ifdef TEST
+    fprintf(stderr, "%s: remote [%d (%s)] -> local [%d]\n", __func__, remote, string, local);
+    #endif
     XFree(string);
 
     return local;
