@@ -25,6 +25,7 @@
 
 #include "dixstruct.h"
 #include "../../fb/fb.h"
+#include "misc.h"
 
 #include "Agent.h"
 #include "Display.h"
@@ -71,8 +72,8 @@
 /*
  * If defined, send the XClearArea at the end
  * of the loop synchronizing the shadow pixmap.
- * In this way, large images can be splitted but
- * the user will see more updates togheter.
+ * In this way, large images can be split but
+ * the user will see more updates together.
  */
 
 #undef  COLLECTED_UPDATES
@@ -643,7 +644,7 @@ int nxagentSynchronizeRegion(DrawablePtr pDrawable, RegionPtr pRegion, unsigned
     fprintf(stderr, "nxagentSynchronizeRegion: WARNING! Failed to allocate memory for synchronization.\n");
 
     /*
-     * Print detailed informations if the
+     * Print detailed information if the
      * image length is zero.
      */
 
@@ -696,11 +697,11 @@ int nxagentSynchronizeRegion(DrawablePtr pDrawable, RegionPtr pRegion, unsigned
 
     for (y = box.y1; y < box.y2; y += h)
     {
-      h = MIN(box.y2 - y, tileHeight);
+      h = min(box.y2 - y, tileHeight);
 
       for (x = box.x1; x < box.x2; x += w)
       {
-        w = MIN(box.x2 - x, tileWidth);
+        w = min(box.x2 - x, tileWidth);
 
         /*
          * FIXME: This should not occur.
@@ -2645,8 +2646,8 @@ void nxagentCreateDrawableBitmap(DrawablePtr pDrawable)
 
   /*
    * Should create a function to append
-   * a bitmap to another, instead of de-
-   * stroy the old one.
+   * a bitmap to another, instead of
+   * destroying the old one.
    */
 
   if (nxagentDrawableBitmap(pDrawable) != NullPixmap)
