@@ -192,9 +192,9 @@ int nxagentX2go;
  * Checking if agent is x2go agent
  */
 
-void checkX2goAgent()
+void checkX2goAgent(void)
 {
-  extern const char *nxagentProgName;
+  extern char *nxagentProgName;
   if( strcasecmp(nxagentProgName,"x2goagent") == 0)
   {
     fprintf(stderr, "\nrunning as X2Go Agent\n");
@@ -220,11 +220,6 @@ void InitOutput(ScreenInfo *screenInfo, int argc, char *argv[])
 
   #endif
 
-  /*
-   * Check if we running as X2Go Agent
-   */
-  checkX2goAgent();
-
   /*
    * Print our pid and version information.
    */
