@@ -142,7 +142,7 @@ void nxagentWaitDisplay(void);
 void nxagentListRemoteFonts(const char *, int);
 
 unsigned int nxagentWMtimeout = 0;
-Bool         nxagentWMPassed  = 0;
+Bool         nxagentWMPassed  = False;
 
 /*
  * Timeouts based on screen saver time.
@@ -540,7 +540,7 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
 #if defined(DDXBEFORERESET)
     ddxBeforeReset ();
 #endif
-    /* FIXME: maybe move the code upto the KillAllClients() call to ddxBeforeReset? */
+    /* FIXME: maybe move the code up to the KillAllClients() call to ddxBeforeReset? */
     if ((dispatchException & DE_RESET) && 
             (serverGeneration > nxagentMaxAllowedResets))
     {
