@@ -458,6 +458,16 @@ Bool nxagentReconnectSession(void)
 
   nxagentProcessOptions(nxagentOptionsFilenameOrString);
 
+  if (nxagentKeyboard && (strcmp(nxagentKeyboard, "null/null") == 0))
+  {
+    #ifdef TEST
+    fprintf(stderr, "nxagentReconnect: changing nxagentKeyboard from [null/null] to [clone].\n");
+    #endif
+
+    free(nxagentKeyboard);
+    nxagentKeyboard = strdup("clone");
+  }
+
   if (nxagentReconnectDisplay(reconnectLossyLevel[DISPLAY_STEP]) == 0)
   {
     failedStep = DISPLAY_STEP;
@@ -584,10 +594,25 @@ Bool nxagentReconnectSession(void)
     goto nxagentReconnectError;
   }
 
+  /* Update remote XKB information */
+  nxagentGetRemoteXkbExtension();
+
+  /* if there's no keyboard definition in the options file
+     restore the previous value. */
+  #ifdef DEBUG
+  fprintf(stderr, "%s: nxagentKeyboard [%s] nxagentOldKeyboard [%s]\n", __func__, nxagentKeyboard, nxagentOldKeyboard);
+  #endif
+  if (nxagentKeyboard == NULL)
+  {
+    nxagentKeyboard = nxagentOldKeyboard;
+    nxagentOldKeyboard = NULL;
+  }
+
   if (nxagentOption(ResetKeyboardAtResume) == 1 &&
          (nxagentKeyboard  == NULL || nxagentOldKeyboard == NULL ||
              strcmp(nxagentKeyboard, nxagentOldKeyboard) != 0 ||
-                 strcmp(nxagentKeyboard, "query") == 0))
+                 strcmp(nxagentKeyboard, "query") == 0 ||
+                     strcmp(nxagentKeyboard, "clone") == 0))
   {
     if (nxagentResetKeyboard() == 0)
     {
@@ -605,7 +630,7 @@ Bool nxagentReconnectSession(void)
   }
   else
   {
-    nxagentResetKeycodeConversion();
+    nxagentKeycodeConversionSetup();
   }
 
   nxagentXkbState.Initialized = 0;
