@@ -258,7 +258,7 @@ char *PngCompressData(XImage *image, int *compressed_size)
   /*
    * TODO: Be sure the padded bytes are cleaned.
    * It would be better to set to zero the bytes
-   * that are not alligned to the word boundary
+   * that are not aligned to the word boundary
    * at the end of the procedure.
    */
 
@@ -283,6 +283,7 @@ char *PngCompressData(XImage *image, int *compressed_size)
                 bitsPerPixel);
     #endif
 
+    free(image_index);
     return NULL;
   }
 
@@ -315,6 +316,7 @@ char *PngCompressData(XImage *image, int *compressed_size)
     fprintf(stderr, "******PngCompressData: PANIC! Failed creating the png_create_write_struct.\n");
     #endif
 
+    free(image_index);
     return NULL;
   }
 
@@ -327,6 +329,7 @@ char *PngCompressData(XImage *image, int *compressed_size)
     #endif
 
     png_destroy_write_struct(&png_ptr, NULL);
+    free(image_index);
 
     return NULL;
   }
@@ -338,6 +341,7 @@ char *PngCompressData(XImage *image, int *compressed_size)
     #endif
 
     png_destroy_write_struct(&png_ptr, &info_ptr);
+    free(image_index);
 
     return NULL;
   }
@@ -360,6 +364,8 @@ char *PngCompressData(XImage *image, int *compressed_size)
                 PNG_DEST_SIZE(w, h));
     #endif
 
+    free(image_index);
+
     return NULL;
   }
 
@@ -372,7 +378,6 @@ char *PngCompressData(XImage *image, int *compressed_size)
     #endif
 
     png_destroy_write_struct(&png_ptr, &info_ptr);
-
     free(pngCompBuf);
 
     return NULL;
@@ -470,6 +475,7 @@ char *PngCompressData(XImage *image, int *compressed_size)
     png_destroy_write_struct(&png_ptr, &info_ptr);
 
     free(pngCompBuf);
+    free(image_index);
 
     return NULL;
   }
@@ -485,13 +491,15 @@ char *PngCompressData(XImage *image, int *compressed_size)
                   (int) (w * sizeof(CARD8)));
       #endif
 
+      free(image_index);
+
       return NULL;
     }
 
     /*
      * TODO: Be sure the padded bytes are cleaned.
      * It would be better to set to zero the bytes
-     * that are not alligned to the word boundary
+     * that are not aligned to the word boundary
      * at the end of the procedure.
      */
 
@@ -516,6 +524,7 @@ char *PngCompressData(XImage *image, int *compressed_size)
     #endif
 
     free(pngCompBuf);
+    free(image_index);
 
     return NULL;
   }
