@@ -30,15 +30,11 @@ THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #define XkbAllocClientMap		SrvXkbAllocClientMap
 #define XkbAllocServerMap		SrvXkbAllocServerMap
 #define XkbChangeTypesOfKey		SrvXkbChangeTypesOfKey
-#define	XkbAddKeyType			SrvXkbAddKeyType
-#define XkbCopyKeyType			SrvXkbCopyKeyType
 #define XkbCopyKeyTypes			SrvXkbCopyKeyTypes
 #define XkbFreeClientMap		SrvXkbFreeClientMap
 #define XkbFreeServerMap		SrvXkbFreeServerMap
-#define XkbInitCanonicalKeyTypes	SrvXkbInitCanonicalKeyTypes
 #define	XkbKeyTypesForCoreSymbols	SrvXkbKeyTypesForCoreSymbols
 #define	XkbApplyCompatMapToKey		SrvXkbApplyCompatMapToKey
-#define	XkbUpdateMapFromCore		SrvXkbUpdateMapFromCore
 #define XkbResizeKeyActions		SrvXkbResizeKeyActions
 #define XkbResizeKeySyms		SrvXkbResizeKeySyms
 #define XkbResizeKeyType		SrvXkbResizeKeyType
@@ -48,21 +44,13 @@ THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #define XkbAllocKeyboard		SrvXkbAllocKeyboard
 #define XkbAllocNames			SrvXkbAllocNames
 #define XkbFreeCompatMap		SrvXkbFreeCompatMap
-#define XkbFreeControls			SrvXkbFreeControls
-#define XkbFreeIndicatorMaps		SrvXkbFreeIndicatorMaps
 #define XkbFreeKeyboard			SrvXkbFreeKeyboard
 #define XkbFreeNames			SrvXkbFreeNames
-#define	XkbAddDeviceLedInfo		SrvXkbAddDeviceLedInfo
-#define	XkbAllocDeviceInfo		SrvXkbAllocDeviceInfo
-#define	XkbFreeDeviceInfo		SrvXkbFreeDeviceInfo
-#define	XkbResizeDeviceButtonActions	SrvXkbResizeDeviceButtonActions
 #define XkbLatchModifiers		SrvXkbLatchModifiers
 #define XkbLatchGroup			SrvXkbLatchGroup
 #define XkbVirtualModsToReal		SrvXkbVirtualModsToReal
 #define	XkbChangeKeycodeRange		SrvXkbChangeKeycodeRange
 #define	XkbApplyVirtualModChanges	SrvXkbApplyVirtualModChanges
-#define	XkbUpdateActionVirtualMods	SrvXkbUpdateActionVirtualMods
-#define XkbUpdateKeyTypeVirtualMods	SrvXkbUpdateKeyTypeVirtualMods
 
 #include <nx-X11/extensions/XKBproto.h>
 #include "xkbstr.h"
@@ -276,23 +264,18 @@ typedef struct
 
 extern int	XkbReqCode;
 extern int	XkbEventBase;
-extern int	XkbKeyboardErrorCode;
 extern int	XkbDisableLockActions;
 extern char *	XkbBaseDirectory;
 extern char *	XkbBinDirectory;
-extern char *	XkbInitialMap;
 extern int	_XkbClientMajor;
 extern int	_XkbClientMinor;
 extern unsigned	int XkbXIUnsupported;
 
-extern char *	XkbModelUsed,*XkbLayoutUsed,*XkbVariantUsed,*XkbOptionsUsed;
 extern Bool	noXkbExtension;
-extern Bool	XkbWantRulesProp;
 
 extern void *	XkbLastRepeatEvent;
 
 extern CARD32	xkbDebugFlags;
-extern CARD32	xkbDebugCtrls;
 
 
 #define	_XkbAlloc(s)		malloc((s))
@@ -450,11 +433,6 @@ extern	Status	XkbAllocControls(
 	unsigned int		/* which*/
 );
 
-extern	Status	XkbCopyKeyType(
-    XkbKeyTypePtr		/* from */,
-    XkbKeyTypePtr		/* into */
-);
-
 extern	Status	XkbCopyKeyTypes(
     XkbKeyTypePtr		/* from */,
     XkbKeyTypePtr		/* into */,
@@ -622,15 +600,6 @@ extern void XkbApplyLedStateChanges(
     XkbEventCausePtr		/* cause */
 );
 
-extern void XkbUpdateLedAutoState(
-    DeviceIntPtr		/* dev */,
-    XkbSrvLedInfoPtr		/* sli */,
-    unsigned int		/* maps_to_check */,
-    xkbExtensionDeviceNotify *	/* ed */,
-    XkbChangesPtr		/* changes */,
-    XkbEventCausePtr		/* cause */
-);
-
 extern void XkbFlushLedEvents(	
     DeviceIntPtr		/* dev */,
     DeviceIntPtr		/* kbd */,
@@ -640,11 +609,6 @@ extern void XkbFlushLedEvents(
     XkbEventCausePtr		/* cause */
 );
 
-extern void XkbUpdateAllDeviceIndicators(
-    XkbChangesPtr		/* changes */,
-    XkbEventCausePtr		/* cause */
-);
-
 extern unsigned int XkbIndicatorsToUpdate(
     DeviceIntPtr		/* dev */,
     unsigned long		/* state_changes */,
@@ -701,12 +665,6 @@ extern	void XkbSendCompatMapNotify(
 	xkbCompatMapNotify *	/* ev */
 );
 
-extern	void XkbSendIndicatorNotify(
-       DeviceIntPtr		/* kbd */,
-       int			/* xkbType */,
-       xkbIndicatorNotify *	/* ev */
-);
-
 extern	void XkbHandleBell(
        BOOL		/* force */,
        BOOL		/* eventOnly */,
@@ -879,11 +837,6 @@ extern void XkbDDXChangeControls(
 	XkbControlsPtr 	/* new */
 );
 
-extern void XkbDDXUpdateIndicators(
-	DeviceIntPtr	/* keybd */,
-	CARD32		/* newState */
-);
-
 extern void XkbDDXUpdateDeviceIndicators(
 	DeviceIntPtr		/* dev */,
 	XkbSrvLedInfoPtr	/* sli */,
@@ -1057,35 +1010,12 @@ extern Bool XkbUpdateMapFromCore(
 	XkbChangesPtr		/* changes */
 );
 
-extern void XkbFreeControls(
-	XkbDescPtr		/* xkb */,
-	unsigned int		/* which */,
-	Bool			/* freeMap */
-);
-
-extern void XkbFreeIndicatorMaps(
-	XkbDescPtr		/* xkb */
-);
-
 extern Bool XkbApplyVirtualModChanges(
 	XkbDescPtr		/* xkb */,
 	unsigned int		/* changed */,
 	XkbChangesPtr		/* changes */
 );
 
-extern Bool XkbUpdateActionVirtualMods(
-	XkbDescPtr		/* xkb */,
-	XkbAction *		/* act */,
-	unsigned int		/* changed */
-);
-
-extern void XkbUpdateKeyTypeVirtualMods(
-	XkbDescPtr		/* xkb */,
-	XkbKeyTypePtr		/* type */,
-	unsigned int		/* changed */,
-	XkbChangesPtr		/* changes */
-);
-
 extern void XkbSendNewKeyboardNotify(
 	DeviceIntPtr		/* kbd */,
 	xkbNewKeyboardNotify *	/* pNKN */
@@ -1116,16 +1046,6 @@ typedef struct _XkbSrvListInfo {
 	int		nFound[_XkbListNumComponents];
 } XkbSrvListInfoRec,*XkbSrvListInfoPtr;
 
-char *
-XkbGetRulesDflts(
-	XkbRF_VarDefsPtr	/* defs */
-);
-
-extern void	XkbSetRulesUsed(
-	XkbRF_VarDefsPtr	/* defs */
-);
-
-
 extern	Status	XkbDDXList(
 	DeviceIntPtr		/* dev */,
 	XkbSrvListInfoPtr	/* listing */,
@@ -1149,11 +1069,6 @@ extern	Bool XkbDDXNamesFromRules(
 	XkbComponentNamesPtr	/* names */
 );
 
-extern	FILE *XkbDDXOpenConfigFile(
-	char *	/* mapName */,
-	char *	/* fileNameRtrn */,
-	int	/* fileNameRtrnLen */
-);
 
 extern	Bool XkbDDXApplyConfig(
 	XPointer	/* cfg_in */,
