@@ -766,11 +766,17 @@ int what;
 	    screenContext[i] = CreateGC((DrawablePtr)pWin, (BITS32) 0,
 					(XID *)NULL, &status);
 	    if (!screenContext[i])
+	    {
+		free(prect);
 		return;
+	    }
 	    numGCs++;
 	    if (!AddResource(FakeClientID(0), ResType,
 			     (void *)screenContext[i]))
-	        return;
+	    {
+		free(prect);
+		return;
+	    }
 	}
 	pGC = screenContext[i];
 	newValues[SUBWINDOW].val = IncludeInferiors;
