@@ -769,7 +769,7 @@ ScreenSaverTimeoutExpire(OsTimerPtr timer,CARD32 now,void * arg)
     if (timeout < ScreenSaverTime)
     {
        return nextTimeout > 0 ?
-               MIN(ScreenSaverTime - timeout, nextTimeout) :
+               min(ScreenSaverTime - timeout, nextTimeout) :
                ScreenSaverTime - timeout;
     }
 
@@ -779,7 +779,7 @@ ScreenSaverTimeoutExpire(OsTimerPtr timer,CARD32 now,void * arg)
     if (ScreenSaverInterval > 0)
     {
        nextTimeout = nextTimeout > 0 ?
-               MIN(ScreenSaverInterval, nextTimeout) :
+               min(ScreenSaverInterval, nextTimeout) :
                ScreenSaverInterval;
     }
 
@@ -823,7 +823,7 @@ SetScreenSaverTimer(void)
     if (ScreenSaverTime > 0)
     {
        timeout = timeout > 0 ?
-               MIN(ScreenSaverTime, timeout) :
+               min(ScreenSaverTime, timeout) :
                ScreenSaverTime;
     }
 
