@@ -301,7 +301,8 @@ ReadRequestFromClient(ClientPtr client)
 	 */
 
 	oci->lenLastReq = 0;
-	if (needed > MAXBUFSIZE)
+#ifdef BIGREQS
+	if (needed > maxBigRequestSize << 2)
 	{
 	    /* request is too big for us to handle */
 	    /*
@@ -312,6 +313,7 @@ ReadRequestFromClient(ClientPtr client)
 	    oci->lenLastReq = gotnow;
 	    return needed;
 	}
+#endif
 	if ((gotnow == 0) ||
 	    ((oci->bufptr - oci->buffer + needed) > oci->size))
 	{
@@ -1120,7 +1122,12 @@ FlushClient(ClientPtr who, OsCommPtr oc, const void *__extraBuf, int extraCount)
 		unsigned char *obuf = NULL;
 
 		if (notWritten + BUFSIZE <= INT_MAX) {
-		    obuf = realloc(oco->buf, notWritten + BUFSIZE);
+		    obuf = calloc(1, notWritten + BUFSIZE);
+		    if (obuf)
+		    {
+			memmove(obuf, oco->buf, oco->size);
+			free(oco->buf);
+		    }
 		}
 		if (!obuf)
 		{
