@@ -40,9 +40,9 @@ THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #include <ctype.h>
 
 static unsigned int _xkbServerGeneration;
-int xkbDevicePrivateIndex = -1;
+static int xkbDevicePrivateIndex = -1;
 
-void
+static void
 xkbUnwrapProc(DeviceIntPtr device, DeviceHandleProc proc,
                    void * data)
 {
@@ -215,7 +215,7 @@ static XkbAction 	fake;
     return fake;
 }
 
-XkbAction
+static XkbAction
 XkbGetButtonAction(DeviceIntPtr kbd,DeviceIntPtr dev,int button)
 {
 XkbAction fake;
@@ -996,7 +996,6 @@ _XkbFilterSwitchScreen(	XkbSrvInfoPtr	xkbi,
     return 1;
 }
 
-#ifdef XFree86Server
 static int
 _XkbFilterXF86Private(	XkbSrvInfoPtr	xkbi,
 			XkbFilterPtr	filter,
@@ -1018,7 +1017,6 @@ _XkbFilterXF86Private(	XkbSrvInfoPtr	xkbi,
     }
     return 1;
 }
-#endif
 
 #ifdef XINPUT
 
@@ -1248,12 +1246,10 @@ xkbDeviceInfoPtr xkbPrivPtr = XKBDEVICEINFO(dev);
 		    sendEvent= _XkbFilterDeviceBtn(xkbi,filter,key,&act);
 		    break;
 #endif
-#ifdef XFree86Server
 		case XkbSA_XFree86Private:
 		    filter = _XkbNextFreeFilter();
 		    sendEvent= _XkbFilterXF86Private(xkbi,filter,key,&act);
 		    break;
-#endif
 	    }
 	}
     }
